@@ -1,6 +1,7 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2016, Teo Mrnjavac <teo@kde.org>
+ *   Copyright 2017, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -59,16 +60,14 @@ KeyboardLayoutModel::data( const QModelIndex& index, int role ) const
 void
 KeyboardLayoutModel::init()
 {
-    QMap< QString, KeyboardGlobal::KeyboardInfo > layouts =
-            KeyboardGlobal::getKeyboardLayouts();
-    for ( QMap< QString, KeyboardGlobal::KeyboardInfo >::const_iterator it = layouts.constBegin();
-          it != layouts.constEnd(); ++it )
-    {
+    KeyboardGlobal::LayoutsMap layouts =
+        KeyboardGlobal::getKeyboardLayouts();
+    for ( KeyboardGlobal::LayoutsMap::const_iterator it = layouts.constBegin();
+            it != layouts.constEnd(); ++it )
         m_layouts.append( qMakePair( it.key(), it.value() ) );
-    }
 
     std::stable_sort( m_layouts.begin(), m_layouts.end(), []( const QPair< QString, KeyboardGlobal::KeyboardInfo >& a,
-                                                              const QPair< QString, KeyboardGlobal::KeyboardInfo >& b )
+                      const QPair< QString, KeyboardGlobal::KeyboardInfo >& b )
     {
         return a.second.description < b.second.description;
     } );
