@@ -2,7 +2,7 @@
  *   Copyright 2016, Luca Giambonini <almack@chakraos.org>
  *   Copyright 2016, Lisa Vitolo <shainer@chakraos.org>
  *   Copyright 2017, Kyle Robbertze  <krobbertze@gmail.com>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,6 +22,8 @@
 
 #include "JobQueue.h"
 #include "GlobalStorage.h"
+
+#include "utils/CalamaresUtils.h"
 #include "utils/Logger.h"
 
 #include "NetInstallPage.h"
@@ -179,17 +181,15 @@ NetInstallViewStep::onLeave()
 void
 NetInstallViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    m_widget->setRequired(
-        configurationMap.contains( "required" ) &&
-        configurationMap.value( "required" ).type() == QVariant::Bool &&
-        configurationMap.value( "required" ).toBool() );
+    m_widget->setRequired( CalamaresUtils::getBool( configurationMap, "required", false ) );
 
-    if ( configurationMap.contains( "groupsUrl" ) &&
-            configurationMap.value( "groupsUrl" ).type() == QVariant::String )
+    QString groupsUrl = CalamaresUtils::getString( configurationMap, "groupsUrl" );
+    if ( !groupsUrl.isEmpty() )
     {
-        Calamares::JobQueue::instance()->globalStorage()->insert(
-            "groupsUrl", configurationMap.value( "groupsUrl" ).toString() );
-        m_widget->loadGroupList();
+        // Keep putting groupsUrl into the global storage,
+        // even though it's no longer used for in-module data-passing.
+        Calamares::JobQueue::instance()->globalStorage()->insert( "groupsUrl", groupsUrl );
+        m_widget->loadGroupList( groupsUrl );
     }
 }
 
