@@ -49,6 +49,10 @@ public:
 
     void swapDevice( Device* oldDevice, Device* newDevice );
 
+    void addDevice( Device* device );
+
+    void removeDevice( Device* device );
+
 private:
     QList< Device* > m_devices;
 };
