@@ -20,6 +20,7 @@
 #ifndef PARTITIONCOREMODULE_H
 #define PARTITIONCOREMODULE_H
 
+#include "core/PartitionLayout.h"
 #include "core/PartitionModel.h"
 #include "Typedefs.h"
 
@@ -128,6 +129,12 @@ public:
 
     void createPartitionTable( Device* device, PartitionTable::TableType type );
 
+    /**
+     * @brief Add a job to do the actual partition-creation.
+     *
+     * If @p flags is not FlagNone, then the given flags are
+     * applied to the newly-created partition.
+     */
     void createPartition( Device* device, Partition* partition,
                           PartitionTable::Flags flags = PartitionTable::FlagNone );
 
@@ -149,6 +156,12 @@ public:
 
     void setBootLoaderInstallPath( const QString& path );
 
+    void initLayout();
+    void initLayout( const QVariantList& config );
+
+    void layoutApply( Device *dev, qint64 firstSector, qint64 lastSector, QString luksPassphrase );
+    void layoutApply( Device *dev, qint64 firstSector, qint64 lastSector, QString luksPassphrase, PartitionNode* parent, const PartitionRole& role );
+
     /**
      * @brief jobs creates and returns a list of jobs which can then apply the changes
      * requested by the user.
@@ -178,7 +191,12 @@ public:
 
     void revert();                      // full revert, thread safe, calls doInit
     void revertAllDevices();            // convenience function, calls revertDevice
-    void revertDevice( Device* dev );   // rescans a single Device and updates DeviceInfo
+    /** @brief rescans a single Device and updates DeviceInfo
+     *
+     * When @p individualRevert is true, calls refreshAfterModelChange(),
+     * used to reduce number of refreshes when calling revertAllDevices().
+     */
+    void revertDevice( Device* dev, bool individualRevert=true );
     void asyncRevertDevice( Device* dev, std::function< void() > callback ); //like revertDevice, but asynchronous
 
     void clearJobs();   // only clear jobs, the Device* states are preserved
@@ -240,6 +258,7 @@ private:
     bool m_hasRootMountPoint = false;
     bool m_isDirty = false;
     QString m_bootLoaderInstallPath;
+    PartitionLayout* m_partLayout;
 
     void doInit();
     void updateHasRootMountPoint();
