@@ -22,7 +22,17 @@
 #include <QRadioButton>
 
 class ClickableLabel;
+class QComboBox;
+class QGridLayout;
+class QHBoxLayout;
 
+/** @brief A radio button with fancy label next to it.
+ *
+ * The radio button itself can be retrieved with buttonWidget(),
+ * and the whole behaves a lot like a label. Extra options can be
+ * added to the display (options are hidden when the button is
+ * not selected) with addOptionsComboBox().
+ */
 class PrettyRadioButton : public QWidget
 {
     Q_OBJECT
@@ -40,9 +50,18 @@ public:
 
     virtual QRadioButton* buttonWidget() const;
 
+    /** @brief Add an options drop-down to this button. */
+    void addOptionsComboBox( QComboBox* );
+
+protected slots:
+    /// Options are hidden when the radio button is off
+    void toggleOptions( bool checked );
+
 protected:
     ClickableLabel* m_label;
     QRadioButton* m_radio;
+    QGridLayout* m_mainLayout;
+    QHBoxLayout* m_optionsLayout;
 };
 
 #endif // PRETTYRADIOBUTTON_H
